import pandas as pd
import numpy as np
import dask.dataframe as dd
import dask.array as da
from typing import Union, Tuple, Optional, Dict, Any, List
from argparse import Namespace
import warnings
import dask_quik.utils as du

try:
    import dask_cudf as dc
    import cudf
except ImportError:
    warnings.warn(
        "dask_quik.cartesian unable to import GPU libraries, \
        importing a dummy dc.DataFrame"
    )
    import dask_quik.dummy as dc

# allow the ability of a dask_cudf.DataFrame or a dd.DataFrame
dc_dd = Union[dc.DataFrame, dd.DataFrame]


def left_merge_cols(
    left: dc_dd, right: dc_dd, cols: Dict[str, Any], col_list: List[str]
) -> dc_dd:
    """Simple left merge.

    Args:
        left (dc_dd): left DataFrame to merge
        right (dc_dd): right DataFrame to merge
        cols (Dict[str, Any]): dictionary of all column types and column names
        col_list (List[str]): names of columns to merge on

    Returns:
        dc_dd: final merged dataframe
    """
    on_cols = list(du.subdict(cols, col_list).values())
    left = left.merge(right, how="left", on=on_cols)
    return left



#!/usr/bin/env python

from setuptools import setup, find_packages
from os import path, system

here = path.abspath(path.dirname(__file__))

with open(path.join(here, "requirements.txt")) as f:
    all_reqs = f.read().split("\n")

removes = ["git+"]
if system("nvidia-smi -L") != 0:
    removes.extend(["cudf", "cuda"])
install_requires = [x.strip() for x in all_reqs if not any(y in x for y in removes)]


setup(
    name="dask_quik",
    version="0.0.1",
    author="Don Chesworth",
    author_email="donald.chesworth@gmail.com",
    packages=find_packages(exclude=["test"]),
    install_requires=install_requires,
)
